import React from 'react';
import cx from 'classnames';
import { SidebarPortal } from '@plone/volto/components';
import FormSidebar from './FormSidebar';
import { Form, Button } from 'semantic-ui-react';

import './form-styling.css';

const Edit = ({ data, onChangeBlock, block, selected, properties }) => {
  function handleAccClick(e, titleProps) {
    const { index } = titleProps;
    onChangeBlock(block, {
      ...data,
      activeFormField: index,
    });
  }

  return (
    <div className={cx('block form')}>
      <div>Formblock</div>
      <Form>
        <>
          {data.formfields &&
            data.formfields.map((item, index) => {
              switch (item.fieldgroup) {
                case 'input':
                  return (
                    <>
                      <Form.Input
                        key={index}
                        index={index}
                        fluid
                        label={item.label}
                        placeholder={item.placeholder}
                        type={item.type}
                        required={item.required}
                        {...item.attributes}
                      />
                      <Button
                        key={item.index}
                        index={index}
                        title="Bearbeiten"
                        aria-label="Bearbeiten"
                        onClick={handleAccClick}
                      >
                        Bearbeiten
                      </Button>
                    </>
                  );
                case 'textarea':
                  return (
                    <>
                      <Form.TextArea
                        key={index}
                        index={index}
                        label={item.label}
                        placeholder={item.placeholder}
                        required={item.required}
                        {...item.attributes}
                      />
                      <Button
                        key={item.index}
                        index={index}
                        title="Bearbeiten"
                        aria-label="Bearbeiten"
                        onClick={handleAccClick}
                      >
                        Bearbeiten
                      </Button>
                    </>
                  );
                default:
                  return (
                    <>
                      <div>No Fields yet</div>
                    </>
                  );
              }
            })}
        </>
        <div>
          {data.formactions &&
            data.formactions.map((item, index) => (
              <Button
                key={item.index}
                index={index}
                title={item.submitButtonText}
                aria-label={item.submitButtonText}
                id="formactionbutton"
              >
                {item.submitButtonText ? item.submitButtonText : 'Submit'}
              </Button>
            ))}
        </div>
      </Form>
      <SidebarPortal selected={selected}>
        <FormSidebar data={data} block={block} onChangeBlock={onChangeBlock} />
      </SidebarPortal>
    </div>
  );
};

Edit.displayName = 'FormEdit';
export default Edit;
